## [Get started](#get-started)

## Alpha releases
Within aterminal run the command `pip install --extra-index-url https://test.pypi.org/simple/ project-visualization-tool-GDeLuisi`
  

## Stable and test releases
Within aterminal run the command `pip install project-visualization-tool-GDeLuisi` for stable and test releases(not yet available).

